@@ -1,60 +1,45 @@
 #!/usr/bin/env python
-
-from pyshortcuts.version import version as __version__
-
+"""
+pyshortcuts
+"""
 import os
 import sys
+from pathlib import Path
 from argparse import ArgumentParser, RawDescriptionHelpFormatter
-from collections import namedtuple
 
-UserFolders = namedtuple("UserFolders", ("home", "desktop", "startmenu"))
+from .version import version as __version__
+from .utils import (fix_filename, new_filename, fix_varname,
+                    isotime, bytes2str, str2bytes, strict_ascii,
+                    pathname, read_textfile,
+                    get_homedir, get_cwd, mkdir,
+                    uname, scut_ext, ico_ext, get_pyexe)
 
-uname = sys.platform
-if os.name == "nt":
-    uname = "win"
-if uname == "linux2":
-    uname = "linux"
-
-from .linux import (scut_ext, ico_ext, make_shortcut,
-                    get_folders, get_homedir, get_desktop)
-
-if uname.startswith('win'):
-    from .windows import (scut_ext, ico_ext, make_shortcut,
-                          get_folders, get_homedir, get_desktop)
+from .gformat import gformat, fcompact
+from .debugtimer import debugtimer, sleep
 
+make_shortcut =  get_folders = None
+if uname.startswith('lin'):
+    from .linux import make_shortcut, get_folders
 elif uname.startswith('darwin'):
-    from .darwin import (scut_ext, ico_ext, make_shortcut,
-                         get_folders, get_homedir, get_desktop)
+    from .darwin import make_shortcut, get_folders
+elif uname.startswith('win'):
+    from .windows import make_shortcut, get_folders
 
-from .shortcut import shortcut, Shortcut, fix_filename
+# back compat
+platform = uname
 
-# for back-compat
-from . import utils
-utils.get_homedir = get_homedir
-utils.get_folders = get_folders
-utils.platform = platform = uname
-
-def get_cwd():
-    """get current working directory
-    Note: os.getcwd() can fail with permission error.
-
-    when that happens, this changes to the users `HOME` directory
-    and returns that directory so that it always returns an existing
-    and readable directory.
-    """
-    try:
-        return os.getcwd()
-    except:
-        home = get_homedir()
-        os.chdir(home)
-        return home
+from .shortcut import shortcut, Shortcut
 
 try:
     import wx
-    HAS_WX = True
     from .wxgui import ShortcutFrame
 except ImportError:
-    HAS_WX = False
+    ShortCutFrame = None
+
+
+def get_desktop():
+    "get desktop folder, for back compatibility"
+    return get_folders().desktop
 
 
 def shortcut_cli():
@@ -62,10 +47,8 @@ def shortcut_cli():
     command-line interface to creating desktop shortcuts
     '''
     desc = 'create desktop and start menu shortcuts'
-    version_string = 'pyshortcut %s' % (__version__)
 
-
-    parser = ArgumentParser(description=desc, # version=version_string,
+    parser = ArgumentParser(description=desc,
                             formatter_class=RawDescriptionHelpFormatter)
 
 
@@ -84,6 +67,9 @@ def shortcut_cli():
     parser.add_argument('-e', '--executable', dest='exe', default=None,
                         help='name of executable to use (python)')
 
+    parser.add_argument('-x', '--no-executable', dest='noexe', action='store_true',
+                        default=False, help='use no implied executable [False]')
+
     parser.add_argument('-t', '--terminal', dest='terminal', action='store_true',
                         default=True, help='run script in a Terminal [True]')
 
@@ -108,9 +94,9 @@ def shortcut_cli():
     args = parser.parse_args()
 
     if args.version:
-        print("pyshortcuts {:s}".format(__version__))
+        print(f"pyshortcut {__version__}")
 
-    if (args.wxgui or args.bootstrap) and not HAS_WX:
+    if (args.wxgui or args.bootstrap) and ShortcutFrame is None:
         print("wxpython is required to run GUI")
         sys.exit()
 
@@ -118,10 +104,12 @@ def shortcut_cli():
         bindir = 'bin'
         if uname.startswith('win'):
             bindir = 'Scripts'
-        here, this = os.path.split(os.path.abspath(__file__))
-        icon = os.path.join(here, 'icons', 'ladder.%s' % ico_ext[0])
-        script = "%s --wxgui" % os.path.join(sys.prefix, bindir, 'pyshortcut')
-        make_shortcut(script, name='PyShortcut', terminal=False, icon=icon)
+        fpath = Path(__file__)
+        icon = Path(fpath.parent, 'icons', f'ladder.{ico_ext[0]}'
+                        ).resolve().as_posix()
+        script = Path(sys.prefix, bindir, 'pyshortcut').resolve().as_posix()
+        make_shortcut(f"{script} --wxgui", name='PyShortcut',
+                      terminal=False, icon=icon)
 
     elif args.wxgui:
         app = wx.App()
@@ -133,9 +121,20 @@ def shortcut_cli():
             args.terminal = False
 
         if args.scriptname is None:
-            print("pyshortcut: must provide one script.  try 'pyshortcuts -h'")
+            print("pyshortcut: must provide one script.  try 'pyshortcut -h'")
         else:
-            make_shortcut(args.scriptname, name=args.name, 
+            p_icon = Path(args.icon).resolve()
+            if p_icon.exists():
+                icon = p_icon.resolve().as_posix()
+            else:
+                parent = p_icon.parent
+                stem  = p_icon.stem
+                for ext in ico_ext:
+                    x = Path(parent, f"{stem}.{ext}").absolute()
+                    if x.exists():
+                        icon = x.resolve().as_posix()
+            make_shortcut(args.scriptname, name=args.name,
                           terminal=args.terminal, folder=args.folder,
-                          icon=args.icon, desktop=args.desktop,
-                          startmenu=args.startmenu, executable=args.exe)
+                          icon=icon, desktop=args.desktop,
+                          startmenu=args.startmenu, executable=args.exe,
+                          noexe=args.noexe)
